@@ -37,8 +37,13 @@ def load_superhero_powers(verbose=False,read_csv_kwds={}):
     url = "https://raw.githubusercontent.com/learn-co-students/dsc-data-cleaning-project-online-ds-ft-100719/master/super_hero_powers.csv"
     return  read_csv_from_url(url, verbose=verbose,read_csv_kwds=read_csv_kwds)
 
-def load_titanic(verbose=False,read_csv_kwds={}):
-    url ="https://raw.githubusercontent.com/jirvingphd/dsc-dealing-missing-data-lab-online-ds-ft-100719/master/titanic.csv"
+def load_titanic(verbose=False,kaggle=False,read_csv_kwds={}):
+    if kaggle:
+        url="https://raw.githubusercontent.com/jirvingphd/fsds/master/datafiles/titanic.csv.gz"
+        if verbose:
+            print('[i] For dataset details, see https://www.kaggle.com/heptapod/titanic')
+    else:
+        url ="https://raw.githubusercontent.com/jirvingphd/dsc-dealing-missing-data-lab-online-ds-ft-100719/master/titanic.csv"
     return  read_csv_from_url(url, verbose=verbose,read_csv_kwds=read_csv_kwds)
 
 
@@ -154,9 +159,9 @@ def load_height_weight(verbose=False,read_csv_kwds={}):
 def load_iowa_prisoners(verbose=False,vers='raw',read_csv_kwds={}):
     import pandas as pd
     if 'raw' in vers:
-        url ='https://raw.githubusercontent.com/jirvingphd/dsc-3-final-project-online-ds-ft-021119/master/datasets/FULL_3-Year_Recidivism_for_Offenders_Released_from_Prison_in_Iowa.csv'
+        url ='https://raw.githubusercontent.com/jirvingphd/iowa-prisoner-recidivism-mod-3-project/b6a92d1474c3eee790ab894f79751d69578bfb18/datasets/FULL_3-Year_Recidivism_for_Offenders_Released_from_Prison_in_Iowa.csv'
     else:
-        url = 'https://raw.githubusercontent.com/jirvingphd/dsc-3-final-project-online-ds-ft-021119/master/datasets/Iowa_Prisoners_Renamed_Columns_fsds_100719.csv'
+        url = 'https://raw.githubusercontent.com/jirvingphd/iowa-prisoner-recidivism-mod-3-project/b6a92d1474c3eee790ab894f79751d69578bfb18/datasets/Iowa_Prisoners_Renamed_Columns_fsds_100719.csv'
     df = read_csv_from_url(url, verbose=verbose,read_csv_kwds=read_csv_kwds)#pd.read_csv(url_iowa_raw,index_col=0)
     #pd.set_option('display.precision',3)
     return df
@@ -321,4 +326,20 @@ def load_hotel_bookings(read_csv_kwds={"encoding":'latin-1'}):
 
 def load_videogame_sales(read_csv_kwds={}):
     url="https://raw.githubusercontent.com/jirvingphd/fsds/master/datafiles/vgsales.csv"
-    return read_csv_from_url(url,verbose=False, read_csv_kwds=read_csv_kwds)
\ No newline at end of file
+    return read_csv_from_url(url,verbose=False, read_csv_kwds=read_csv_kwds)
+
+
+
+
+
+def load_king_county_housing(verbose=False,project_vers=True, read_csv_kwds={}):
+    if project_vers==True:
+        if verbose:
+            print('[i] Loading the project-version of the dataset.')
+        url = "https://github.com/jirvingphd/fsds/raw/master/datafiles/king-county-housing-project-version.csv.gz"
+    else:
+        if verbose:
+            print('[i] Loading the kaggle-version of the dataset.')
+        url = "https://github.com/jirvingphd/fsds/raw/master/datafiles/king-county-housing-kaggle-version.csv.gz"
+    return  read_csv_from_url(url, verbose=verbose,read_csv_kwds=read_csv_kwds)
+        
\ No newline at end of file
